@@ -15,9 +15,10 @@ class ZoneStatus(IntFlag):
     FAULT = 2
     TROUBLE = 8  # is also Tampered
     TAMPER = 16 # Tamper for ProA7, see #176
+    COMMUNICATION_FAILURE = 32 # see #191
     LOW_BATTERY = 64
     TRIGGERED = 256
-    KNOWN = NORMAL | BYPASSED | FAULT | TROUBLE | TAMPER | LOW_BATTERY | TRIGGERED
+    KNOWN = NORMAL | BYPASSED | FAULT | TROUBLE | TAMPER | COMMUNICATION_FAILURE | LOW_BATTERY | TRIGGERED
 
 
 class ZoneType(Enum):
